@@ -1,6 +1,7 @@
 package command
 
 import (
+	"fmt"
 	"path/filepath"
 	"testing"
 
@@ -341,3 +342,42 @@ func TestValidateCommand_VarFilesDisableWarnOnUndeclared(t *testing.T) {
 		})
 	}
 }
+
+func TestValidateCommand_ShowLineNumForMissing(t *testing.T) {
+	tt := []struct {
+		path      string
+		exitCode  int
+		extraArgs []string
+	}{
+		{path: filepath.Join(testFixture("validate-invalid"), "missing_build_block.pkr.hcl"), exitCode: 1},
+	}
+
+	for _, tc := range tt {
+		t.Run(tc.path, func(t *testing.T) {
+			c := &ValidateCommand{
+				Meta: TestMetaFile(t),
+			}
+			tc := tc
+			args := tc.extraArgs
+			args = append(args, tc.path)
+			if code := c.Run(args); code != tc.exitCode {
+				fatalCommand(t, c.Meta)
+			}
+
+			stdout, stderr := GetStdoutAndErrFromTestMeta(t, c.Meta)
+			expected := fmt.Sprintf(`Error: Unknown source file.cho
+
+  on %s line 6:
+  (source code not available)
+
+Known: [file.chocolate]
+
+
+`, tc.path)
+			if diff := cmp.Diff(expected, stderr); diff != "" {
+				t.Errorf("Unexpected output: %s", diff)
+			}
+			t.Log(stdout)
+		})
+	}
+}
