@@ -359,7 +359,10 @@ func (cfg *PackerConfig) evaluateDatasources(skipExecution bool) hcl.Diagnostics
 			continue
 		}
 
+		dsOpts, _ := decodeHCL2Spec(body, cfg.EvalContext(DatasourceContext, nil), datasource)
+		sp := packer.CheckpointReporter.AddSpan(ref.Type, "datasource", dsOpts)
 		realValue, err := datasource.Execute()
+		sp.End(err)
 		if err != nil {
 			diags = append(diags, &hcl.Diagnostic{
 				Summary:  err.Error(),
@@ -441,7 +444,10 @@ func (cfg *PackerConfig) recursivelyEvaluateDatasources(ref DatasourceRef, depen
 		return dependencies, diags, shouldContinue
 	}
 
+	opts, _ := decodeHCL2Spec(ds.block.Body, cfg.EvalContext(DatasourceContext, nil), datasource)
+	sp := packer.CheckpointReporter.AddSpan(ref.Type, "datasource", opts)
 	realValue, err := datasource.Execute()
+	sp.End(err)
 	if err != nil {
 		diags = append(diags, &hcl.Diagnostic{
 			Summary:  err.Error(),
@@ -486,6 +492,8 @@ func (cfg *PackerConfig) getCoreBuildProvisioner(source SourceUseBlock, pb *Prov
 		return packer.CoreBuildProvisioner{}, diags
 	}
 
+	flatProvisionerCfg, _ := decodeHCL2Spec(pb.HCL2Ref.Rest, ectx, provisioner)
+
 	// If we're pausing, we wrap the provisioner in a special pauser.
 	if pb.PauseBefore != 0 {
 		provisioner = &packer.PausedProvisioner{
@@ -509,6 +517,7 @@ func (cfg *PackerConfig) getCoreBuildProvisioner(source SourceUseBlock, pb *Prov
 		PType:       pb.PType,
 		PName:       pb.PName,
 		Provisioner: provisioner,
+		HCLConfig:   flatProvisionerCfg,
 	}, diags
 }
 
@@ -547,10 +556,13 @@ func (cfg *PackerConfig) getCoreBuildPostProcessors(source SourceUseBlock, block
 				continue
 			}
 
+			flatPostProcessorCfg, moreDiags := decodeHCL2Spec(ppb.HCL2Ref.Rest, ectx, postProcessor)
+
 			pps = append(pps, packer.CoreBuildPostProcessor{
 				PostProcessor:     postProcessor,
 				PName:             ppb.PName,
 				PType:             ppb.PType,
+				HCLConfig:         flatPostProcessorCfg,
 				KeepInputArtifact: ppb.KeepInputArtifact,
 			})
 		}
@@ -653,6 +665,9 @@ func (cfg *PackerConfig) GetBuilds(opts packer.GetBuildsOptions) ([]packersdk.Bu
 				continue
 			}
 
+			decoded, _ := decodeHCL2Spec(srcUsage.Body, cfg.EvalContext(BuildContext, nil), builder)
+			pcb.HCLConfig = decoded
+
 			// If the builder has provided a list of to-be-generated variables that
 			// should be made accessible to provisioners, pass that list into
 			// the provisioner prepare() so that the provisioner can appropriately
