@@ -13,13 +13,13 @@ func (r nullRegistry) PopulateIteration(context.Context) error {
 	return nil
 }
 
-func (r nullRegistry) StartBuild(context.Context, string) error {
+func (r nullRegistry) StartBuild(context.Context, sdkpacker.Build) error {
 	return nil
 }
 
 func (r nullRegistry) CompleteBuild(
 	ctx context.Context,
-	buildName string,
+	build sdkpacker.Build,
 	artifacts []sdkpacker.Artifact,
 	buildErr error,
 ) ([]sdkpacker.Artifact, error) {
